@@ -15,15 +15,8 @@ function change(message, suffix) {
 	if(check) window.location.href=suffix;
 }
 
-function mdel_old(message) {
-	check=confirm(message);
-  if(check) document.FormName.submit();
-}
-
-function mdel(message) {
-	check=confirm(message);
-//  if(check) document.FormName.submit();
-  return check;
+function mdel(but, message) {
+	return confirm(message);
 }
 
 function callurl( url ) {
